==> adfurikun-1.3.0.tar.gz: android/src/main/kotlin/jp/co/glossom/adfurikun/AdfurikunPlugin.kt <==
package jp.co.glossom.adfurikun

import android.app.Activity
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import jp.tjkapp.adfurikunsdk.moviereward.AdfurikunSdk

/** AdfurikunPlugin */
class AdfurikunPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {

  private lateinit var channel : MethodChannel

  private var nativeAdFactory: AdfurikunNativeAdFactory? = null
  private var rectangleFactory: AdfurikunRectangleFactory? = null
  private var bannerFactory: AdfurikunBannerFactory? = null

  private var rewardMap = hashMapOf<Int, AdfurikunReward>()
  private var interstitialMap = hashMapOf<Int, AdfurikunInterstitial>()

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    AdfurikunSdk.init(flutterPluginBinding.applicationContext)
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, Constants.MAIN_METHOD_CHANNEL)
    channel.setMethodCallHandler(this)
    nativeAdFactory = AdfurikunNativeAdFactory(flutterPluginBinding.binaryMessenger, channel)
    flutterPluginBinding.platformViewRegistry.registerViewFactory(Constants.NATIVE_AD_VIEW_TYPE_ID, nativeAdFactory)
    rectangleFactory = AdfurikunRectangleFactory(flutterPluginBinding.binaryMessenger, channel)
    flutterPluginBinding.platformViewRegistry.registerViewFactory(Constants.RECTANGLE_VIEW_TYPE_ID, rectangleFactory)
    bannerFactory = AdfurikunBannerFactory(flutterPluginBinding.binaryMessenger, channel)
    flutterPluginBinding.platformViewRegistry.registerViewFactory(Constants.BANNER_VIEW_TYPE_ID, bannerFactory)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    val arguments = (call.arguments as? HashMap<String, *>)
    when (call.method) {
      // リワード
      Constants.INIT_REWARD -> initReward(arguments)
      Constants.LOAD_REWARD -> loadReward(arguments)
      Constants.IS_PREPARED_REWARD -> isPreparedReward(arguments, result)
      Constants.PLAY_REWARD -> playReward(arguments)
      Constants.DESTROY_REWARD -> destroyReward(arguments)
      // インタースティシャル
      Constants.INIT_INTERSTITIAL -> initInterstitial(arguments)
      Constants.LOAD_INTERSTITIAL -> loadInterstitial(arguments)
      Constants.IS_PREPARED_INTERSTITIAL -> isPreparedInterstitial(arguments, result)
      Constants.PLAY_INTERSTITIAL -> playInterstitial(arguments)
      Constants.DESTROY_INTERSTITIAL -> destroyInterstitial(arguments)
      // ネイティブ
      Constants.INIT_NATIVE_AD,
      Constants.LOAD_NATIVE_AD,
      Constants.PLAY_NATIVE_AD,
      Constants.DESTROY_NATIVE_AD -> nativeAdFactory?.onMethodCall(call, result)
      // レクタングル
      Constants.INIT_RECTANGLE,
      Constants.LOAD_RECTANGLE,
      Constants.PLAY_RECTANGLE,
      Constants.DESTROY_RECTANGLE -> rectangleFactory?.onMethodCall(call, result)
      // バナー
      Constants.INIT_BANNER,
      Constants.LOAD_BANNER,
      Constants.PLAY_BANNER,
      Constants.DESTROY_BANNER -> bannerFactory?.onMethodCall(call, result)
      // 音
      Constants.SET_SOUND_STATE -> AdfurikunCommons.setSoundState(arguments)
      // テストモード
      Constants.SET_TEST_MODE -> AdfurikunCommons.setTestMode(arguments)
      // ユーザーGDPR同意
      Constants.SET_USER_CONSENT -> AdfurikunCommons.setUserConsent(arguments)
      else -> result.notImplemented()
    }
  }

  /**
   * 初期化（リワード）
   * @param arguments
   */
  private fun initReward(arguments: HashMap<String, *>?) {
    val number = (arguments?.get(Constants.KEY_NUMBER) as? Int) ?: -1
    val appId = (arguments?.get(Constants.KEY_ID) as? String) ?: ""
    if (appId.isNotBlank() && number >= 0 && !rewardMap.containsKey(number)) {
      AdfurikunCommons.setPluginVersion(arguments)
      val reward = AdfurikunReward(number, appId, channel)
      reward.init()
      rewardMap[number] = reward
    }
  }

  /**
   * 読み込み（リワード）
   * @param arguments
   */
  private fun loadReward(arguments: HashMap<String, *>?) {
    checkRewardArgument(arguments)?.let {
      rewardMap[it]?.load()
    }
  }

  /**
   * 準備判定（リワード）
   * @param arguments
   * @param result
   */
  private fun isPreparedReward(arguments: HashMap<String, *>?, result: Result) {
    checkRewardArgument(arguments)?.let {
      rewardMap[it]?.isPrepared(result)
    }
  }

  /**
   * 再生（リワード）
   * @param arguments
   */
  private fun playReward(arguments: HashMap<String, *>?) {
    checkRewardArgument(arguments)?.let {
      rewardMap[it]?.play(convertCustomParams(arguments))
    }
  }

  /**
   * 破棄（リワード）
   * @param arguments
   */
  private fun destroyReward(arguments: HashMap<String, *>?) {
    checkRewardArgument(arguments)?.let {
      rewardMap.remove(it)?.destroy()
    }
  }

  /**
   * Argument判定（リワード）
   * @param arguments
   */
  private fun checkRewardArgument(arguments: HashMap<String, *>?): Int? {
    val number = (arguments?.get(Constants.KEY_NUMBER) as? Int) ?: -1
    val appId = (arguments?.get(Constants.KEY_ID) as? String) ?: ""
    return if (appId.isNotBlank() && rewardMap.containsKey(number)) number else null
  }

  /**
   * 初期化（インタースティシャル）
   * @param arguments
   */
  private fun initInterstitial(arguments: HashMap<String, *>?) {
    val number = (arguments?.get(Constants.KEY_NUMBER) as? Int) ?: -1
    val appId = (arguments?.get(Constants.KEY_ID) as? String) ?: ""
    if (appId.isNotBlank() && number >= 0 && !interstitialMap.containsKey(number)) {
      AdfurikunCommons.setPluginVersion(arguments)
      val interstitial = AdfurikunInterstitial(number, appId, channel)
      interstitial.init()
      interstitialMap[number] = interstitial
    }
  }

  /**
   * 読み込み（インタースティシャル）
   * @param arguments
   */
  private fun loadInterstitial(arguments: HashMap<String, *>?) {
    checkInterstitialArgument(arguments)?.let {
      interstitialMap[it]?.load()
    }
  }

  /**
   * 準備判定（インタースティシャル）
   * @param arguments
   * @param result
   */
  private fun isPreparedInterstitial(arguments: HashMap<String, *>?, result: Result) {
    checkInterstitialArgument(arguments)?.let {
      interstitialMap[it]?.isPrepared(result)
    }
  }

  /**
   * 再生（インタースティシャル）
   * @param arguments
   */
  private fun playInterstitial(arguments: HashMap<String, *>?) {
    checkInterstitialArgument(arguments)?.let {
      interstitialMap[it]?.play(convertCustomParams(arguments))
    }
  }

  /**
   * 破棄（インタースティシャル）
   * @param arguments
   */
  private fun destroyInterstitial(arguments: HashMap<String, *>?) {
    checkInterstitialArgument(arguments)?.let {
      interstitialMap.remove(it)?.destroy()
    }
  }

  /**
   * Argument判定（インタースティシャル）
   * @param arguments
   */
  private fun checkInterstitialArgument(arguments: HashMap<String, *>?): Int? {
    val number = (arguments?.get(Constants.KEY_NUMBER) as? Int) ?: -1
    val appId = (arguments?.get(Constants.KEY_ID) as? String) ?: ""
    return if (appId.isNotBlank() && interstitialMap.containsKey(number)) number else null
  }

  /**
   * CustomParamsを変換
   * @param arguments
   */
  private fun convertCustomParams(arguments: HashMap<String, *>?): HashMap<String, String>? {
    (arguments?.get(Constants.KEY_CUSTOM_PARAMS) as? HashMap<String, String>)?.let {
      if (it.isNotEmpty()) {
        return it
      }
    }
    return null
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    currentActivity = binding.activity
  }

  override fun onDetachedFromActivity() {
    // 処理なし
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    // 処理なし
  }

  override fun onDetachedFromActivityForConfigChanges() {
    // 処理なし
  }

  companion object {
    internal var currentActivity: Activity? = null
  }
}

==> adfurikun-1.5.0.tar.gz: android/src/main/kotlin/jp/co/glossom/adfurikun/AdfurikunPlugin.kt <==
package jp.co.glossom.adfurikun

import android.app.Activity
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import jp.tjkapp.adfurikunsdk.moviereward.AdfurikunSdk

/** AdfurikunPlugin */
class AdfurikunPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {

  private lateinit var channel : MethodChannel

  private var nativeAdFactory: AdfurikunNativeAdFactory? = null
  private var rectangleFactory: AdfurikunRectangleFactory? = null
  private var bannerFactory: AdfurikunBannerFactory? = null

  private var rewardMap = hashMapOf<Int, AdfurikunReward>()
  private var interstitialMap = hashMapOf<Int, AdfurikunInterstitial>()

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    AdfurikunSdk.init(flutterPluginBinding.applicationContext)
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, Constants.MAIN_METHOD_CHANNEL)
    channel.setMethodCallHandler(this)
    nativeAdFactory = AdfurikunNativeAdFactory(flutterPluginBinding.binaryMessenger, channel)
    nativeAdFactory?.let {
      flutterPluginBinding.platformViewRegistry.registerViewFactory(Constants.NATIVE_AD_VIEW_TYPE_ID, it)
    }
    rectangleFactory = AdfurikunRectangleFactory(flutterPluginBinding.binaryMessenger, channel)
    rectangleFactory?.let {
      flutterPluginBinding.platformViewRegistry.registerViewFactory(Constants.RECTANGLE_VIEW_TYPE_ID, it)
    }
    bannerFactory = AdfurikunBannerFactory(flutterPluginBinding.binaryMessenger, channel)
    bannerFactory?.let {
      flutterPluginBinding.platformViewRegistry.registerViewFactory(Constants.BANNER_VIEW_TYPE_ID, it)
    }
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    val arguments = (call.arguments as? HashMap<String, *>)
    when (call.method) {
      // リワード
      Constants.INIT_REWARD -> initReward(arguments)
      Constants.LOAD_REWARD -> loadReward(arguments)
      Constants.IS_PREPARED_REWARD -> isPreparedReward(arguments, result)
      Constants.PLAY_REWARD -> playReward(arguments)
      Constants.DESTROY_REWARD -> destroyReward(arguments)
      // インタースティシャル
      Constants.INIT_INTERSTITIAL -> initInterstitial(arguments)
      Constants.LOAD_INTERSTITIAL -> loadInterstitial(arguments)
      Constants.IS_PREPARED_INTERSTITIAL -> isPreparedInterstitial(arguments, result)
      Constants.PLAY_INTERSTITIAL -> playInterstitial(arguments)
      Constants.DESTROY_INTERSTITIAL -> destroyInterstitial(arguments)
      // ネイティブ
      Constants.INIT_NATIVE_AD,
      Constants.LOAD_NATIVE_AD,
      Constants.PLAY_NATIVE_AD,
      Constants.DESTROY_NATIVE_AD -> nativeAdFactory?.onMethodCall(call, result)
      // レクタングル
      Constants.INIT_RECTANGLE,
      Constants.LOAD_RECTANGLE,
      Constants.PLAY_RECTANGLE,
      Constants.DESTROY_RECTANGLE -> rectangleFactory?.onMethodCall(call, result)
      // バナー
      Constants.INIT_BANNER,
      Constants.LOAD_BANNER,
      Constants.PLAY_BANNER,
      Constants.DESTROY_BANNER -> bannerFactory?.onMethodCall(call, result)
      // 音
      Constants.SET_SOUND_STATE -> AdfurikunCommons.setSoundState(arguments)
      // テストモード
      Constants.SET_TEST_MODE -> AdfurikunCommons.setTestMode(arguments)
      // ユーザーGDPR同意
      Constants.SET_USER_CONSENT -> AdfurikunCommons.setUserConsent(arguments)
      // 地域
      Constants.SET_REGION -> AdfurikunCommons.setRegion(arguments)
      else -> result.notImplemented()
    }
  }

  /**
   * 初期化（リワード）
   * @param arguments
   */
  private fun initReward(arguments: HashMap<String, *>?) {
    val number = (arguments?.get(Constants.KEY_NUMBER) as? Int) ?: -1
    val appId = (arguments?.get(Constants.KEY_ID) as? String) ?: ""
    if (appId.isNotBlank() && number >= 0 && !rewardMap.containsKey(number)) {
      AdfurikunCommons.setPluginVersion(arguments)
      val reward = AdfurikunReward(number, appId, channel)
      reward.init()
      rewardMap[number] = reward
    }
  }

  /**
   * 読み込み（リワード）
   * @param arguments
   */
  private fun loadReward(arguments: HashMap<String, *>?) {
    checkRewardArgument(arguments)?.let {
      rewardMap[it]?.load(AdfurikunCommons.getLoadWithTimeout(arguments))
    }
  }

  /**
   * 準備判定（リワード）
   * @param arguments
   * @param result
   */
  private fun isPreparedReward(arguments: HashMap<String, *>?, result: Result) {
    checkRewardArgument(arguments)?.let {
      rewardMap[it]?.isPrepared(result)
    }
  }

  /**
   * 再生（リワード）
   * @param arguments
   */
  private fun playReward(arguments: HashMap<String, *>?) {
    checkRewardArgument(arguments)?.let {
      rewardMap[it]?.play(convertCustomParams(arguments))
    }
  }

  /**
   * 破棄（リワード）
   * @param arguments
   */
  private fun destroyReward(arguments: HashMap<String, *>?) {
    checkRewardArgument(arguments)?.let {
      rewardMap.remove(it)?.destroy()
    }
  }

  /**
   * Argument判定（リワード）
   * @param arguments
   */
  private fun checkRewardArgument(arguments: HashMap<String, *>?): Int? {
    val number = (arguments?.get(Constants.KEY_NUMBER) as? Int) ?: -1
    val appId = (arguments?.get(Constants.KEY_ID) as? String) ?: ""
    return if (appId.isNotBlank() && rewardMap.containsKey(number)) number else null
  }

  /**
   * 初期化（インタースティシャル）
   * @param arguments
   */
  private fun initInterstitial(arguments: HashMap<String, *>?) {
    val number = (arguments?.get(Constants.KEY_NUMBER) as? Int) ?: -1
    val appId = (arguments?.get(Constants.KEY_ID) as? String) ?: ""
    if (appId.isNotBlank() && number >= 0 && !interstitialMap.containsKey(number)) {
      AdfurikunCommons.setPluginVersion(arguments)
      val interstitial = AdfurikunInterstitial(number, appId, channel)
      interstitial.init()
      interstitialMap[number] = interstitial
    }
  }

  /**
   * 読み込み（インタースティシャル）
   * @param arguments
   */
  private fun loadInterstitial(arguments: HashMap<String, *>?) {
    checkInterstitialArgument(arguments)?.let {
      interstitialMap[it]?.load(AdfurikunCommons.getLoadWithTimeout(arguments))
    }
  }

  /**
   * 準備判定（インタースティシャル）
   * @param arguments
   * @param result
   */
  private fun isPreparedInterstitial(arguments: HashMap<String, *>?, result: Result) {
    checkInterstitialArgument(arguments)?.let {
      interstitialMap[it]?.isPrepared(result)
    }
  }

  /**
   * 再生（インタースティシャル）
   * @param arguments
   */
  private fun playInterstitial(arguments: HashMap<String, *>?) {
    checkInterstitialArgument(arguments)?.let {
      interstitialMap[it]?.play(convertCustomParams(arguments))
    }
  }

  /**
   * 破棄（インタースティシャル）
   * @param arguments
   */
  private fun destroyInterstitial(arguments: HashMap<String, *>?) {
    checkInterstitialArgument(arguments)?.let {
      interstitialMap.remove(it)?.destroy()
    }
  }

  /**
   * Argument判定（インタースティシャル）
   * @param arguments
   */
  private fun checkInterstitialArgument(arguments: HashMap<String, *>?): Int? {
    val number = (arguments?.get(Constants.KEY_NUMBER) as? Int) ?: -1
    val appId = (arguments?.get(Constants.KEY_ID) as? String) ?: ""
    return if (appId.isNotBlank() && interstitialMap.containsKey(number)) number else null
  }

  /**
   * CustomParamsを変換
   * @param arguments
   */
  private fun convertCustomParams(arguments: HashMap<String, *>?): HashMap<String, String>? {
    (arguments?.get(Constants.KEY_CUSTOM_PARAMS) as? HashMap<String, String>)?.let {
      if (it.isNotEmpty()) {
        return it
      }
    }
    return null
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    currentActivity = binding.activity
  }

  override fun onDetachedFromActivity() {
    // 処理なし
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    // 処理なし
  }

  override fun onDetachedFromActivityForConfigChanges() {
    // 処理なし
  }

  companion object {
    internal var currentActivity: Activity? = null
  }
}
